"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = build;

var _webpack = _interopRequireDefault(require("webpack"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _mkdirp = _interopRequireDefault(require("mkdirp"));

var _rimraf = _interopRequireDefault(require("rimraf"));

var _context = _interopRequireDefault(require("./common/context"));

var _warning = _interopRequireDefault(require("./common/utils/warning"));

var _generateEntry = _interopRequireDefault(require("./common/generateEntry"));

var _generateTransfer = _interopRequireDefault(require("./common/generateTransfer"));

var _generateWebpackConfig = _interopRequireDefault(require("./common/generateWebpackConfig"));

var _generateEnvironmentVariable = _interopRequireDefault(require("./common/generateEnvironmentVariable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function copy(fileName) {
  var _context$dwtConfig = _context["default"].dwtConfig,
      output = _context$dwtConfig.output,
      htmlPath = _context$dwtConfig.htmlPath,
      distBasePath = _context$dwtConfig.distBasePath;

  var originPath = _path["default"].join(__dirname, '../../', fileName);

  var distPath = _path["default"].join(process.cwd(), distBasePath, output, fileName);

  _fsExtra["default"].copyFileSync(originPath, distPath);
}

function handleAfterCompile() {
  var COPY_FILE_NAME = ['.env', '.default.env', 'env.sh', 'env-config.js'];
  COPY_FILE_NAME.forEach(function (filename) {
    return copy(filename);
  });
  var _context$dwtConfig2 = _context["default"].dwtConfig,
      output = _context$dwtConfig2.output,
      htmlPath = _context$dwtConfig2.htmlPath,
      distBasePath = _context$dwtConfig2.distBasePath;

  var originPath = _path["default"].join(process.cwd(), output);

  var distPath = _path["default"].join(process.cwd(), distBasePath, output);

  _fsExtra["default"].copySync("".concat(originPath), distPath);
}

function build(program) {
  var env = program.env || process.env.NODE_ENV || 'production'; // 初始化全局参数context

  var initContext = _context["default"].initContext;
  initContext(program);
  var _context$dwtConfig3 = _context["default"].dwtConfig,
      entryName = _context$dwtConfig3.entryName,
      output = _context$dwtConfig3.output,
      htmlPath = _context$dwtConfig3.htmlPath,
      distBasePath = _context$dwtConfig3.distBasePath;

  var distPath = _path["default"].join(process.cwd(), distBasePath, output);

  _rimraf["default"].sync(distPath);

  _mkdirp["default"].sync(distPath); // 生成入口文件


  (0, _generateTransfer["default"])(entryName);
  (0, _generateEntry["default"])(entryName);
  var webpackConfig = (0, _generateWebpackConfig["default"])('build', env, (0, _generateEnvironmentVariable["default"])());
  webpackConfig.plugins.push(new _webpack["default"].DefinePlugin({
    'process.env.NODE_ENV': JSON.stringify(env)
  }));
  (0, _webpack["default"])(webpackConfig, function (err, stats) {
    if (err !== null) {
      (0, _warning["default"])(false, err);
      process.exit(1);
    } else if (stats.hasErrors()) {
      (0, _warning["default"])(false, stats.toString('errors-only'));
      process.exit(1);
    }

    handleAfterCompile();
  });
}