"use strict";

var _context = _interopRequireDefault(require("./context"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var fs = require('fs');

var path = require('path');

function parse(src, options) {
  var debug = Boolean(options && options.debug);
  var obj = {};
  src.toString().split('\n').forEach(function (line, idx) {
    var keyValueArr = line.match(/^\s*([\w.-]+)\s*=\s*(.*)?\s*$/);

    if (keyValueArr != null) {
      var key = keyValueArr[1];
      var value = keyValueArr[2] || '';
      var len = value ? value.length : 0;

      if (len > 0 && value.charAt(0) === '"' && value.charAt(len - 1) === '"') {
        value = value.replace(/\\n/gm, '\n');
      }

      value = value.replace(/(^['"]|['"]$)/g, '').trim();
      obj[key] = value;
    } else if (debug) {
      // eslint-disable-next-line no-console
      console.log("did not match key and value when parsing line ".concat(idx + 1, ": ").concat(line));
    }
  });
  return obj;
}

function config(options) {
  var dotenvPath = path.resolve(process.cwd(), '.env');
  var encoding = 'utf8';
  var debug = false;

  if (options) {
    if (options.path != null) {
      dotenvPath = options.path;
    }

    if (options.encoding != null) {
      // eslint-disable-next-line prefer-destructuring
      encoding = options.encoding;
    }

    if (options.debug != null) {
      debug = true;
    }
  }

  try {
    var parsed = parse(fs.readFileSync(dotenvPath, {
      encoding: encoding
    }), {
      debug: debug
    });
    return {
      parsed: parsed
    };
  } catch (e) {
    return {
      error: e
    };
  }
}
/**
 * 通过node模拟shell脚本生成环境变量文件(env-config.js)过程
 * 检查本地是否有环境变量文件，如果有，复制都boot根目录下
 * 解析用户环境变量文件和默认环境变量文件
 * 进行合并
 * @param {*} isDev 
 */


function generateEnvNode() {
  var isDev = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  var runByBoot = _context["default"].dwtConfig.runByBoot;
  var customEnvPath = path.join(process.cwd(), './react/.env');
  var dirEnvPath = path.join(__dirname, '../../..', '.env');

  if (fs.existsSync(customEnvPath) && !runByBoot) {
    fs.copyFileSync(customEnvPath, dirEnvPath);
  } else {
    fs.writeFile(dirEnvPath, '', 'utf8', function (err, written, buffer) {});
  }

  var customEnv = config({
    path: dirEnvPath
  });
  var defaultEnv = config({
    path: path.join(__dirname, '../../..', '.default.env')
  });
  var combineEnv = isDev ? customEnv.parsed : _objectSpread(_objectSpread({}, defaultEnv.parsed), customEnv.parsed);
  var envConfigPath = path.join(__dirname, '../../..', 'env-config.js');
  fs.writeFileSync(envConfigPath, "window._env_ = ".concat(JSON.stringify(combineEnv), ";"));
  return "window._env_ = ".concat(JSON.stringify(combineEnv), ";");
}

module.exports = generateEnvNode;