"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = generateTransfer;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _nunjucks = _interopRequireDefault(require("nunjucks"));

var _context = _interopRequireDefault(require("./context"));

var _escapeWinPath = _interopRequireDefault(require("./utils/escapeWinPath"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var babelParse = require('@babel/parser').parse;

var traverse = require('@babel/traverse')["default"];

var generate = require('@babel/generator')["default"];

var join = _path["default"].join;

function astFunction(exportPath) {
  if (!exportPath) return null;

  var code = _fs["default"].readFileSync(exportPath, 'utf8');

  var ast = babelParse(code, {
    sourceType: 'module',
    allowImportExportEverywhere: true,
    plugins: ['dynamicImport', 'jsx']
  });
  traverse(ast, {
    // eslint-disable-next-line no-shadow
    ExportNamedDeclaration: function ExportNamedDeclaration(path) {
      if (path.node.source.value.startsWith('.')) {
        path.node.source.value = join(process.cwd(), exportPath.replace(/index.js/, '').replace(/export.js/, ''), path.node.source.value);
      }
    },
    CallExpression: function CallExpression(_ref) {
      var node = _ref.node;

      if (node.callee.name === 'require' && node.arguments[0].value.startsWith('.')) {
        node.arguments[0].value = join(process.cwd(), exportPath.replace(/index.js/, '').replace(/export.js/, ''), node.arguments[0].value);
      }
    }
  });
  return generate(ast, {}, code).code;
}

function generateTransfer(configEntryName) {
  var tmpDirPath = _context["default"].tmpDirPath,
      isDev = _context["default"].isDev,
      master = _context["default"].dwtConfig.master;

  var transferPath = _path["default"].join(tmpDirPath, "transfer.".concat(configEntryName, ".js"));

  var exportPath = master.replace('master.js', 'index.js');
  var content = astFunction(exportPath);

  _fs["default"].writeFileSync(transferPath, content);
}