"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = updateWebpackConfig;

var _fs = _interopRequireDefault(require("fs"));

var _path = require("path");

var _webpack = _interopRequireDefault(require("webpack"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));

var _context = _interopRequireDefault(require("./context"));

var _getStyleLoadersConfig = _interopRequireDefault(require("./webpackConfig/getStyleLoadersConfig"));

var _getWebpackCommonConfig = _interopRequireDefault(require("./webpackConfig/getWebpackCommonConfig"));

var _getDefaultTheme = _interopRequireDefault(require("./webpackConfig/getDefaultTheme"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var dwtLib = (0, _path.join)(__dirname, '..', '..');

function getFilePath(file) {
  var isDev = _context["default"].isDev;
  var filePath = (0, _path.join)(process.cwd(), file);

  if (_fs["default"].existsSync(filePath)) {
    return filePath;
  } else if (isDev) {
    return (0, _path.join)(process.cwd(), 'src', file);
  } else {
    return (0, _path.join)(__dirname, '../../', file);
  }
}

function updateWebpackConfig(mode, env, envStr) {
  var dwtConfig = _context["default"].dwtConfig;
  var theme = dwtConfig.theme,
      output = dwtConfig.output,
      root = dwtConfig.root,
      enterPoints = dwtConfig.enterPoints,
      postcssConfig = dwtConfig.postcssConfig,
      entryName = dwtConfig.entryName,
      titlename = dwtConfig.titlename,
      htmlTemplate = dwtConfig.htmlTemplate,
      favicon = dwtConfig.favicon,
      resourcesLevel = dwtConfig.resourcesLevel,
      outward = dwtConfig.outward;
  var webpackConfig = (0, _getWebpackCommonConfig["default"])(mode, env);
  var styleLoadersConfig = (0, _getStyleLoadersConfig["default"])(postcssConfig, {
    sourceMap: mode === 'start',
    modifyVars: _objectSpread(_objectSpread({}, (0, _getDefaultTheme["default"])(env)), theme)
  });
  webpackConfig.entry = {};

  if (mode === 'start') {
    webpackConfig.output.publicPath = '/';
    webpackConfig.devtool = 'cheap-module-eval-source-map';
    webpackConfig.watch = true;
    styleLoadersConfig.forEach(function (config) {
      webpackConfig.module.rules.push({
        test: config.test,
        use: ['style-loader'].concat(_toConsumableArray(config.use))
      });
    });
  } else if (mode === 'build') {
    webpackConfig.output.publicPath = root;
    webpackConfig.output.path = (0, _path.join)(process.cwd(), output);
    styleLoadersConfig.forEach(function (config) {
      webpackConfig.module.rules.push({
        test: config.test,
        use: [_miniCssExtractPlugin["default"].loader].concat(_toConsumableArray(config.use))
      });
    });
  }

  var mergedEnterPoints = _objectSpread({
    NODE_ENV: env,
    RESOURCES_LEVEL: Array.isArray(resourcesLevel) ? resourcesLevel.join(',') : resourcesLevel,
    OUTWARD: outward
  }, enterPoints(mode, env));

  var defines = Object.keys(mergedEnterPoints).reduce(function (obj, key) {
    obj["process.env.".concat(key)] = JSON.stringify(process.env[key] || mergedEnterPoints[key]);
    return obj;
  }, {});
  var customizedWebpackConfig = dwtConfig.webpackConfig(webpackConfig, _webpack["default"]);

  if (customizedWebpackConfig.entry[entryName]) {
    throw new Error("Should not set `webpackConfig.entry.".concat(entryName, "`!"));
  }

  var entryPath = (0, _path.join)(dwtLib, '..', 'tmp', "entry.".concat(entryName, ".js"));
  customizedWebpackConfig.entry[entryName] = entryPath;
  customizedWebpackConfig.plugins.push(new _webpack["default"].DefinePlugin(defines), new _htmlWebpackPlugin["default"]({
    title: process.env.TITLE_NAME || titlename,
    template: getFilePath(htmlTemplate),
    inject: true,
    // chunks: ['vendor', entryName],
    favicon: getFilePath(favicon),
    env: envStr,
    minify: {
      html5: true,
      collapseWhitespace: true,
      removeComments: true,
      removeTagWhitespace: true,
      removeEmptyAttributes: true,
      removeStyleLinkTypeAttributes: true
    }
  }));
  return customizedWebpackConfig;
}