"use strict";

var path = require('path');

var gulp = require('gulp');

var rimraf = require('rimraf');

var babel = require('gulp-babel');

var through2 = require('through2');

var cwd = process.cwd();
var libDir = path.join(cwd, 'lib');

function compileAssets() {
  return gulp.src(['react/**/*.@(jpg|png|svg|scss|less|css|html|ico)']).pipe(gulp.dest(libDir));
}

function getBabelCommonConfig() {
  var plugins = ['@babel/plugin-proposal-export-default-from', '@babel/plugin-proposal-export-namespace-from', ['@babel/plugin-proposal-decorators', {
    legacy: true
  }], ['@babel/plugin-proposal-class-properties', {
    loose: true
  }], ['babel-plugin-import', {
    libraryName: 'dwt-ui',
    style: true
  }, 'dwt-ui'], ['babel-plugin-import', {
    libraryName: 'dwt-ui/pro',
    style: true
  }, 'dwt-ui-pro'], 'babel-plugin-lodash', ['babel-plugin-try-import', {
    tryImport: 'DwtTryImport',
    hasModule: 'DwtHasModule'
  }]];
  return {
    presets: ['@babel/preset-react', '@babel/preset-env'],
    plugins: plugins
  };
}

function babelify(js) {
  var dir = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var babelConfig = getBabelCommonConfig();
  var stream = js.pipe(babel(babelConfig));
  return stream // eslint-disable-next-line func-names
  .pipe(through2.obj(function (file, encoding, next) {
    var matches = file.path.match(/(routes|dashboard|guide|entry|entrywithoutsider)\.nunjucks\.(js|jsx)/);

    if (matches) {
      var content = file.contents.toString(encoding);
      file.contents = Buffer.from(content.replace("'{{ ".concat(matches[1], " }}'"), "{{ ".concat(matches[1], " }}")) // eslint-disable-next-line quotes
      .replace("'{{ home }}'", '{{ home }}') // eslint-disable-next-line quotes
      .replace("'{{ master }}'", '{{ master }}'));
    }

    this.push(file);
    next();
  })).pipe(gulp.dest(path.join(libDir, dir)));
}

function compileFile() {
  var source = ['react/**/*.js', 'react/**/*.jsx'];
  return babelify(gulp.src(source));
}

function compile() {
  rimraf.sync(libDir);
  compileAssets();
  compileFile();
}

gulp.task('compile', function () {
  compile();
});