"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = getWebpackCommonConfig;

var _path = require("path");

var _webpack = _interopRequireDefault(require("webpack"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

var _webpackFilterWarningsPlugin = _interopRequireDefault(require("webpack-filter-warnings-plugin"));

var _caseSensitivePathsWebpackPlugin = _interopRequireDefault(require("case-sensitive-paths-webpack-plugin"));

var _progressBarWebpackPlugin = _interopRequireDefault(require("progress-bar-webpack-plugin"));

var _friendlyErrorsWebpackPlugin = _interopRequireDefault(require("friendly-errors-webpack-plugin"));

var _webpackThemeColorReplacer = _interopRequireDefault(require("webpack-theme-color-replacer"));

var _chalk = _interopRequireDefault(require("chalk"));

var _getBabelCommonConfig = _interopRequireDefault(require("./getBabelCommonConfig"));

var _getTSCommonConfig = _interopRequireDefault(require("./getTSCommonConfig"));

var _colorPalette = _interopRequireDefault(require("../utils/colorPalette"));

var _context = _interopRequireDefault(require("../context"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var jsFileName = 'dis/[name].[hash:8].js';
var jsChunkFileName = 'dis/chunks/[name].[chunkhash:5].chunk.js';
var cssFileName = 'dis/[name].[contenthash:8].css';
var cssColorFileName = 'dis/theme-colors.css';
var assetFileName = 'dis/assets/[name].[hash:8].[ext]';
var processTimer;
var baseColor = '#3f51b5';

function getAssetLoader(env, mimetype) {
  var limit = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 10000;
  return {
    loader: 'url-loader',
    options: {
      limit: limit,
      mimetype: mimetype,
      name: assetFileName
    }
  };
}

function getWebpackCommonConfig(mode, env) {
  var isDev = _context["default"].isDev,
      _context$dwtConfig$ma = _context["default"].dwtConfig.masterName,
      masterName = _context$dwtConfig$ma === void 0 ? 'master' : _context$dwtConfig$ma;
  var babelOptions = (0, _getBabelCommonConfig["default"])(mode, env);
  var tsOptions = (0, _getTSCommonConfig["default"])();
  var plugins = [new _webpackFilterWarningsPlugin["default"]({
    exclude: /.*@dwt.*/
  }), new _miniCssExtractPlugin["default"]({
    filename: cssFileName,
    chunkFilename: env === 'development' ? '[id].css' : '[id].[hash].css',
    ignoreOrder: true // 不加控制台一堆warn

  }), new _progressBarWebpackPlugin["default"](), new _webpack["default"].ProvidePlugin({
    dwt: isDev ? (0, _path.join)(process.cwd(), "node_modules/@dwt/".concat(masterName, "/lib/containers/common")) : (0, _path.join)(__dirname, "../../../".concat(masterName, "/lib/containers/common"))
  }), new _webpackThemeColorReplacer["default"]({
    fileName: cssColorFileName,
    matchColors: [(0, _colorPalette["default"])(baseColor, 1), (0, _colorPalette["default"])(baseColor, 2), (0, _colorPalette["default"])(baseColor, 3), (0, _colorPalette["default"])(baseColor, 4), (0, _colorPalette["default"])(baseColor, 5), baseColor, (0, _colorPalette["default"])(baseColor, 7), (0, _colorPalette["default"])(baseColor, 8), (0, _colorPalette["default"])(baseColor, 9), (0, _colorPalette["default"])(baseColor, 10), '#303f9f', // 左上角颜色
    '140, 158, 255, 0.12', // menu-item背景
    '140, 158, 255, 0.16' // 左侧菜单menu-item背景
    ],
    injectCss: true,
    isJsUgly: env !== 'development'
  })];

  if (env === 'development') {
    plugins.push(new _friendlyErrorsWebpackPlugin["default"](), new _caseSensitivePathsWebpackPlugin["default"](), new _webpack["default"].HotModuleReplacementPlugin());
  }

  return {
    mode: env,
    output: {
      filename: jsFileName,
      chunkFilename: jsChunkFileName
    },
    optimization: {
      splitChunks: {
        chunks: 'all',
        cacheGroups: {
          libs: {
            name: 'chunk-libs',
            test: /[\\/]node_modules[\\/]/,
            priority: 10,
            chunks: 'initial' // 只打包初始时依赖的第三方

          },
          dwtUI: {
            name: 'chunk-ui',
            // 单独将 UI 拆包
            priority: 20,
            // 权重要大于 libs 和 app 不然会被打包进 libs 或者 app
            test: /[\\/]node_modules[\\/]dwt-ui[\\/]/
          }
        }
      }
    },
    resolve: {
      modules: ['node_modules', (0, _path.join)(__dirname, '../../node_modules')],
      extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json']
    },
    resolveLoader: {
      modules: ['node_modules', (0, _path.join)(__dirname, '../../node_modules')]
    },
    node: {
      fs: 'empty'
    },
    module: {
      noParse: [/moment.js/],
      rules: [{
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        options: babelOptions
      }, {
        test: /\.jsx$/,
        loader: 'babel-loader',
        options: babelOptions
      }, {
        test: /\.tsx?$/,
        use: [{
          loader: 'babel-loader',
          options: babelOptions
        }, {
          loader: 'ts-loader',
          options: {
            transpileOnly: true,
            compilerOptions: tsOptions
          }
        }]
      }, {
        test: /\.woff(\?v=\d+\.\d+\.\d+)?$/,
        use: getAssetLoader(env, 'application/font-woff')
      }, {
        test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/,
        use: getAssetLoader(env, 'application/font-woff')
      }, {
        test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
        use: getAssetLoader(env, 'application/octet-stream')
      }, {
        test: /\.eot(\?v=\d+\.\d+\.\d+)?$/,
        use: getAssetLoader(env, 'application/vnd.ms-fontobject')
      }, {
        test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
        use: getAssetLoader(env, 'image/svg+xml')
      }, {
        test: /\.(png|jpg|jpeg|gif)(\?v=\d+\.\d+\.\d+)?$/i,
        use: getAssetLoader(env)
      }]
    },
    plugins: plugins
  };
}